==> amiya-0.0.1.tar.gz: amiya-0.0.1/setup.py <==
# MIT License
#
# Copyright (c) 2024 Kevin L.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import os
from setuptools import setup, find_packages

setup(
    name='amiya',
    version='0.0.1',
    author='Kevin L.',
    author_email='kevinliu@vt.edu',
    description='A lightweight cross-platform automation tool for games and daily tasks!',
    long_description=open('README.md', encoding='utf-8').read() if os.path.exists('README.md') else '',
    long_description_content_type="text/markdown",
    url='http://github.com/rezeroe/amiya',
    package_dir={'': 'src'},                                                            # Tell setuptools that all packages are under src
    packages=find_packages(where='src'),                                                # Find packages in src directory
    install_requires=open('requirements.txt', encoding='utf-8').read().splitlines(),    # List of dependencies
    python_requires='>=3.6, <4',
    entry_points={
        'console_scripts': [
            'amiya=amiya.entrypoints.entrypoints:start_amiya',
        ],
    },
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Development Status :: 3 - Alpha'
    ],  
    include_package_data=True,
)

==> amiya-0.0.3.tar.gz: amiya-0.0.3/setup.py <==
# MIT License
#
# Copyright (c) 2024 Kevin L.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import os
from setuptools import setup, find_packages

setup(
    name='amiya',
    version='0.0.3',
    author='Kevin L.',
    author_email='kevinliu@vt.edu',
    description='A lightweight cross-platform automation tool for games and daily tasks!',
    long_description=open('README.md', encoding='utf-8').read() if os.path.exists('README.md') else '',
    long_description_content_type="text/markdown",
    url='http://github.com/rezeroe/amiya',
    package_dir={'': 'src'},                                                            # Tell setuptools that all packages are under src
    packages=find_packages(where='src'),                                                # Find packages in src directory
    install_requires=open('requirements.txt', encoding='utf-8').read().splitlines(),    # List of dependencies
    python_requires='>=3.6, <4',
    entry_points={
        'console_scripts': [
            'amiya=amiya.entrypoints.entrypoints:start_amiya_cli_as_admin',
        ],
    },
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Development Status :: 4 - Beta'
    ],  
    include_package_data=True,
)
